part of 'blog_cubit.dart';

abstract class BlogState extends Equatable {
  @override
  List<Object> get props => [];
}

class BlogInitial extends BlogState {
  @override
  String toString() {
    return 'BlogInitial{}';
  }
}

class BlogLoading extends BlogState {
  BlogLoading();

  @override
  String toString() => 'BlogLoading';
}

class BlogFailure extends BlogState {
  final String error;

  BlogFailure(this.error);

  @override
  String toString() => 'BlogFailure { error: $error }';
}

class GetListCatalogSuccess extends BlogState {

  @override
  String toString() => 'GetListCatalogSuccess';
}

class BlogSuccess extends BlogState {
  final String? message;

  BlogSuccess({this.message});

  @override
  String toString() => 'BlogSuccess { message: $message }';
}
